@@ -3,6 +3,7 @@ from otel_extensions import instrumented, inject_context_to_env
 import os
 import subprocess
 import sys
+import pytest
 
 
 @instrumented
@@ -19,12 +20,26 @@ def test_ubai_search_cli():
     def call_cli():
         results = cli("test", ".hex", metadata)
         assert len(results) == 1
+        results = cli(None, None, metadata)
+        assert len(results) == 1
+        results = cli("test", None, metadata)
+        assert len(results) == 1
+        results = cli(None, ".hex", metadata)
+        assert len(results) == 1
 
     call_cli()
 
 
+@pytest.mark.parametrize(
+    "args",
+    [
+        ["--name", "test", "--extension", ".hex"],
+        ["--extension", ".hex"],
+        ["--name", "test"],
+    ],
+)
 @instrumented
-def test_ubai_search_cli_script():
+def test_ubai_search_cli_script(args):
     metadata = [
         ("app_name", "ubai_unit_test"),
         ("branch", "master"),
@@ -33,7 +48,6 @@ def test_ubai_search_cli_script():
         ("target", "brd4180b"),
     ]
 
-    args = ["--name", "test", "--extension", ".hex"]
     for k, v in metadata:
         args += ["--metadata", k, v]
 
