@@ -39,20 +39,15 @@ class UbaiArtifactUploadRequestProducer:
                     f"metadata is missing the following required properties: {','.join(missing_keys)}"
                 )
 
-        name, extension = os.path.splitext(os.path.split(artifact_file)[1])
-        with open(artifact_file, "rb") as f:
-            contents = f.read()
-            base64_content = base64.b64encode(contents).decode("utf-8")
+        name, extension, contents, base64_content = self.extract_payload(artifact_file)
         if len(contents) > MESSAGE_QUEUE_SIZE_LIMIT:
-            artifact_api = ArtifactApi()
-            artifact_input = ArtifactInput(
+            self.upload_artifact_direct(
                 name=name,
                 extension=extension,
                 base64_content=base64_content,
-                validate_metadata=validate_metadata,
                 metadata=metadata,
+                validate_metadata=validate_metadata,
             )
-            artifact_api.upload_artifact(payload=artifact_input)
         else:
             artifact_request = ArtifactUploadRequest(
                 name=name,
@@ -80,6 +75,32 @@ class UbaiArtifactUploadRequestProducer:
             persistent=True,
         )
 
+    @staticmethod
+    def extract_payload(artifact_file: str):
+        name, extension = os.path.splitext(os.path.split(artifact_file)[1])
+        with open(artifact_file, "rb") as f:
+            contents = f.read()
+            base64_content = base64.b64encode(contents).decode("utf-8")
+            return name, extension, contents, base64_content
+
+    @staticmethod
+    def upload_artifact_direct(
+        name: str,
+        extension: str,
+        base64_content: str,
+        metadata: dict,
+        validate_metadata: bool = True,
+    ):
+        artifact_api = ArtifactApi()
+        artifact_input = ArtifactInput(
+            name=name,
+            extension=extension,
+            base64_content=base64_content,
+            validate_metadata=validate_metadata,
+            metadata=metadata,
+        )
+        artifact_api.upload_artifact(payload=artifact_input)
+
 
 class LocalUbaiArtifactUploadRequestProducer(UbaiArtifactUploadRequestProducer):
     def __init__(self):
