@@ -7,6 +7,7 @@ from utf_queue_client.scripts import setup_telemetry
 from otel_extensions import instrumented
 from retry import retry
 from opentelemetry import trace
+from random import random
 
 
 @click.command()
@@ -45,11 +46,15 @@ def cli(
         if extension is not None:
             search_opts.extension = extension
 
-        @retry(Exception, delay=3, backoff=2, max_delay=12, tries=retries + 1)
+        @retry(Exception, delay=5, backoff=2, max_delay=30, tries=retries + 1)
         def retry_wrapper():
             return find_all_artifacts(search_opts)
 
-        return retry_wrapper()
+        # workaround to reduce load
+        sleep(random() * 2.5)
+        results = retry_wrapper()
+        sleep(random() * 2.5)
+        return results
 
 
 @instrumented
