@@ -11,6 +11,7 @@ from retry import retry
 import requests
 from otel_extensions import instrumented
 from opentelemetry import trace
+from random import random
 
 from utf_queue_client.utils import prepare_queue_central_url
 
@@ -72,17 +73,17 @@ def cli(
         for key, value in metadata:
             metadata_dict[key] = value
 
-        @retry(Exception, delay=3, backoff=2, max_delay=12, tries=retries + 1)
+        @retry(Exception, delay=5, backoff=2, max_delay=30, tries=retries + 1)
         def retry_wrapper():
             if queue:
                 upload_artifact_through_queue(url, client_id, file_path, metadata_dict)
             else:
                 upload_artifact_direct(file_path, metadata_dict)
 
+        # load mitigation
+        sleep(random() * 2.5)
         retry_wrapper()
-        if not queue:
-            # workaround to reduce load
-            sleep(2)
+        sleep(random() * 2.5)
 
 
 @instrumented
